def per_of(percent: int,of: int):# % ของ  เท่ากับเท่าไร 
 return (of/100)*percent
def per_is(num1: int,num2: int):# คิดเป็นกี่เปอร์เซ็นต์ของ
 return (num1/num2)*100
def per_from(num: int,percent: int):# เป็น % ของจำนวนใด
 return(num/percent)*100


from setuptools import setup,find_packages

with open("README.md", "r", encoding="utf8") as f:
    long_description = f.read()

setup(name='other_python',
      version='2.3',
      description="upgraded version of calc-plus",
      long_description=long_description,
      long_description_content_type="text/markdown",
      url='https://github.com/keegang6705/other-python',
      author='keegang_6705',
      author_email='darunphobwi@gmail.com',
      license='MIT',
      packages=find_packages(),
      install_requires= [''],
      python_requires='>=3.0',
      zip_safe=False)